
//MPU9150***************************************************************************************
static const nrf_drv_twi_t   m_twi_instance = NRF_DRV_TWI_INSTANCE(0);

/**
 * @brief TWI events handler.
 */
static void twi_handler(nrf_drv_twi_evt_t * p_event)
{   
    // Pass TWI events down to the MPU driver.
    mpu9150_twi_event_handler(p_event);
}

/**
 * @brief TWI initialization.
 * Just the usual way. Nothing special here
 */
void twi_init(void)
{
    ret_code_t err_code;
    
    const nrf_drv_twi_config_t twi_mpu_9150_config = {
       .scl                = MPU9150_TWI_SCL_PIN,
       .sda                = MPU9150_TWI_SDA_PIN,
       .frequency          = NRF_TWI_FREQ_400K,
       .interrupt_priority = APP_IRQ_PRIORITY_HIGH
    };
    
    err_code = nrf_drv_twi_init(&m_twi_instance, &twi_mpu_9150_config, twi_handler);
    APP_ERROR_CHECK(err_code);
    
    nrf_drv_twi_enable(&m_twi_instance);
}

void mpu_init(void)
{
    ret_code_t ret_code;
    // Initiate MPU9150 driver with TWI instance handler
    ret_code = mpu9150_init(&m_twi_instance);
    APP_ERROR_CHECK(ret_code); // Check for errors in return value
    
    // Setup and configure the MPU9150 with intial values
    mpu9150_config_t p_mpu_config = MPU9150_DEFAULT_CONFIG(); // Load default values
    p_mpu_config.smplrt_div = 19;   // Change sampelrate. Sample Rate = Gyroscope Output Rate / (1 + SMPLRT_DIV). 19 gives a sample rate of 50Hz
    p_mpu_config.accel_config.afs_sel = AFS_2G; // Set accelerometer full scale range to 2G
    ret_code = mpu9150_config(&p_mpu_config); // Configure the MPU9150 with above values
    APP_ERROR_CHECK(ret_code); // Check for errors in return value
    
}

static void gpio_blink(uint16_t blk){
		nrf_gpio_pin_toggle(LED_RGB_RED);
		nrf_delay_ms(blk);
		nrf_gpio_pin_toggle(LED_RGB_RED);
		nrf_delay_ms(blk);
}	

//**********************************************************************************************

int main(void)
{
		
    nrf_gpio_cfg_output(0);
    nrf_gpio_pin_set(0);
	
    nrf_gpio_cfg_output(20);
    nrf_gpio_pin_clear(20);
	
    nrf_gpio_cfg_output(LED_RGB_RED);
    nrf_gpio_pin_set(LED_RGB_RED);
	
    gpio_blink(3000);
			
    ble_stack_init();
    gap_params_init();
    advertising_init();
//************************MPU 9150***************************
    twi_init();
    mpu_init();
		
    gpio_blink(3000);
    
    accel_values_t acc_values;
    uint32_t sample_number = 1;
    while(sample_number < 3) 
    {
        // Read accelerometer sensor values
        mpu9150_read_accel(&acc_values);
        
        gpio_blink(3000);
	sample_number = sample_number + 1;
				
    }

    nrf_delay_ms(3000);
    advertising_start();
			
    for (;; )
    {
        power_manage();
    }
}


